# Silicon dioxide, SiO2

## Other names

- Quartz
- Silica
- Silicon oxide
- Silicon(IV) dioxide

## Polymorphs

- Alpha quartz (α-quartz, most common)
- Beta quartz (β-quartz, only stable at temperatures above 573 °C)
- Tridymite
- Cristobalite
- Coesite
- Stishovite
- Lechatelierite
- Chalcedony

## External links

- Silicon dioxide - Wikipedia
- Fused quartz - Wikipedia
- Silicon dioxide - WebElements
- Quartz - The Mineral and Gemstone Kingdom